==> react-amplify-wrapper-1.0.7.tgz: package/epics/auth/signIn/signIn.ts <==
import { ofType, Epic, ActionsObservable } from 'redux-observable'
import { switchMap } from 'rxjs/operators'
import { Observable } from 'rxjs/Observable'
import 'rxjs/add/observable/from'
import 'rxjs/add/observable/of'
import 'rxjs/add/operator/mergeMap'
import 'rxjs/add/operator/catch'
import AuthService from '../../../AuthService'
import { AUTH_ACTION_TYPES } from '../../../actions/types'

type LoginAction = {
    type: string,
    email: string,
    password: string,
}

const signIn: Epic<LoginAction, any, any> = (action$, state$) =>
    action$.pipe(
        ofType(AUTH_ACTION_TYPES.SIGN_IN),
        switchMap(action => {
            const { email, password } = action
            return AuthService.signIn(
                email,
                password
            ).mergeMap(response => {
                if (response.challengeName === 'NEW_PASSWORD_REQUIRED') {
                    return Observable.of(
                        { type: AUTH_ACTION_TYPES.NEW_PASSWORD_REQUIRED, response }
                    )
                }
                return Observable.of(
                    { type: AUTH_ACTION_TYPES.SIGN_IN_SUCCESSFUL, response }
                )
            }).catch(error => {
                if (error.code === 'UserNotConfirmedException') {
                    return  Observable.of(
                        { type: AUTH_ACTION_TYPES.USER_NOT_CONFIRMED, error }
                    )
                }
                return Observable.of(
                    { type: AUTH_ACTION_TYPES.SIGN_IN_FAILED, error },                )
                })
            }))

export default signIn

==> react-amplify-wrapper-1.0.8.tgz: package/epics/auth/signIn/signIn.ts <==
import { ofType, Epic, ActionsObservable } from 'redux-observable'
import { switchMap } from 'rxjs/operators'
import { Observable } from 'rxjs/Observable'
import 'rxjs/add/observable/from'
import 'rxjs/add/observable/of'
import 'rxjs/add/operator/mergeMap'
import 'rxjs/add/operator/catch'
import AuthService from '../../../AuthService'
import { AUTH_ACTION_TYPES } from '../../../actions/types'

type LoginAction = {
    type: string,
    email: string,
    password: string,
}

const signIn: Epic<LoginAction, any, any> = (action$, state$) =>
    action$.pipe(
        ofType(AUTH_ACTION_TYPES.SIGN_IN),
        switchMap(action => {
            const { email, password } = action
            return AuthService.signIn(
                email,
                password
            ).mergeMap(response => {
                if (response.challengeName === 'NEW_PASSWORD_REQUIRED') {
                    return Observable.of(
                        { type: AUTH_ACTION_TYPES.NEW_PASSWORD_REQUIRED, response }
                    )
                }
                return Observable.of(
                    { type: AUTH_ACTION_TYPES.SIGN_IN_SUCCESSFUL, response }
                )
            }).catch(error => {
                if (error.code === 'UserNotConfirmedException') {
                    return  Observable.of(
                        { type: AUTH_ACTION_TYPES.USER_NOT_CONFIRMED, error }
                    )
                }
                return Observable.of(
                    { type: AUTH_ACTION_TYPES.SIGN_IN_FAILED, error },                
                )
                })
            }))

export default signIn
